@@ -32,6 +32,9 @@ def main(source_url, target_name):
     new_repo = user.create_repo(target_name)
 
     copy_directory(source_repo, new_repo)
+    response = f"git_clone.py {source_url}, {target_name}"
+    print(response)
+    return response
 
 
 if __name__ == "__main__":
